:mod:`Shipping`
===============

Models
------
.. automodule:: lfs.shipping.models

   .. autoclass:: ShippingMethod
   .. autoclass:: ShippingMethodPrice
      :members:
   
Utils 
------   
.. automodule:: lfs.shipping.utils

   .. autofunction:: get_valid_shipping_methods
   .. autofunction:: get_default_shipping_method
   .. autofunction:: get_selected_shipping_method
   .. autofunction:: get_shipping_costs